@@ -1,4 +1,4 @@
-from nmcipher.cli.cli import Parser
+from nmcipher.cli import Parser
 from .caesar import Caesar
 
 def encrypt_func(key, message, symbols):
